# ednoflow
EdnoFlow is a framework for simulating dynamic agent-based flows on graphs, where agents move along edges connecting nodes (edge-node flow).

## entities
Current entities are
+ `Node` represents node in graph.
+ `Edge` represents an edge in the graph.
+ `Edge` represents a graph-based network consisting of nodes and edges.
+ `Agent` represents an agent that moves through the graph.
